summaryrefslogtreecommitdiff
path: root/gtk2_ardour/midi_region_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/midi_region_view.h')
-rw-r--r--gtk2_ardour/midi_region_view.h70
1 files changed, 35 insertions, 35 deletions
diff --git a/gtk2_ardour/midi_region_view.h b/gtk2_ardour/midi_region_view.h
index 20a1ee5b25..d08e0177b7 100644
--- a/gtk2_ardour/midi_region_view.h
+++ b/gtk2_ardour/midi_region_view.h
@@ -122,8 +122,8 @@ public:
void resolve_note(uint8_t note_num, Evoral::Beats end_time);
void cut_copy_clear (Editing::CutCopyOp);
- bool paste (framepos_t pos, const ::Selection& selection, PasteContext& ctx, const int32_t sub_num);
- void paste_internal (framepos_t pos, unsigned paste_count, float times, const MidiCutBuffer&);
+ bool paste (samplepos_t pos, const ::Selection& selection, PasteContext& ctx, const int32_t sub_num);
+ void paste_internal (samplepos_t pos, unsigned paste_count, float times, const MidiCutBuffer&);
void add_canvas_patch_change (ARDOUR::MidiModel::PatchChangePtr patch, const std::string& displaytext, bool);
void remove_canvas_patch_change (PatchChange* pc);
@@ -147,7 +147,7 @@ public:
void change_patch_change (PatchChange& old_patch, const MIDI::Name::PatchPrimaryKey& new_patch);
void change_patch_change (ARDOUR::MidiModel::PatchChangePtr, Evoral::PatchChange<Evoral::Beats> const &);
- void add_patch_change (framecnt_t, Evoral::PatchChange<Evoral::Beats> const &);
+ void add_patch_change (samplecnt_t, Evoral::PatchChange<Evoral::Beats> const &);
void move_patch_change (PatchChange &, Evoral::Beats);
void delete_patch_change (PatchChange *);
void edit_patch_change (PatchChange *);
@@ -197,7 +197,7 @@ public:
void delete_note (boost::shared_ptr<NoteType>);
size_t selection_size() { return _selection.size(); }
void select_all_notes ();
- void select_range(framepos_t start, framepos_t end);
+ void select_range(samplepos_t start, samplepos_t end);
void invert_selection ();
Evoral::Beats earliest_in_selection ();
@@ -259,42 +259,42 @@ public:
*/
double snap_to_pixel(double x, bool ensure_snap = false);
- /** Snap a region relative pixel coordinate to frame units.
+ /** Snap a region relative pixel coordinate to sample units.
* @param x a pixel coordinate relative to region start
* @param ensure_snap ignore SnapOff and magnetic snap.
* Required for inverting snap logic with modifier keys and snap delta calculation.
* @return the snapped framepos_t coordinate relative to region start
*/
- framepos_t snap_pixel_to_sample(double x, bool ensure_snap = false);
+ samplepos_t snap_pixel_to_sample(double x, bool ensure_snap = false);
- /** Convert a timestamp in beats into frames (both relative to region position) */
- framepos_t region_beats_to_region_frames(Evoral::Beats beats) const;
- /** Convert a timestamp in beats into absolute frames */
- framepos_t region_beats_to_absolute_frames(Evoral::Beats beats) const {
- return _region->position() + region_beats_to_region_frames (beats);
+ /** Convert a timestamp in beats into samples (both relative to region position) */
+ samplepos_t region_beats_to_region_samples(Evoral::Beats beats) const;
+ /** Convert a timestamp in beats into absolute samples */
+ samplepos_t region_beats_to_absolute_samples(Evoral::Beats beats) const {
+ return _region->position() + region_beats_to_region_samples (beats);
}
- /** Convert a timestamp in frames to beats (both relative to region position) */
- Evoral::Beats region_frames_to_region_beats(framepos_t) const;
- double region_frames_to_region_beats_double(framepos_t) const;
-
- /** Convert a timestamp in beats measured from source start into absolute frames */
- framepos_t source_beats_to_absolute_frames(Evoral::Beats beats) const;
- /** Convert a timestamp in beats measured from source start into region-relative frames */
- framepos_t source_beats_to_region_frames(Evoral::Beats beats) const {
- return source_beats_to_absolute_frames (beats) - _region->position();
+ /** Convert a timestamp in samples to beats (both relative to region position) */
+ Evoral::Beats region_samples_to_region_beats(samplepos_t) const;
+ double region_samples_to_region_beats_double(samplepos_t) const;
+
+ /** Convert a timestamp in beats measured from source start into absolute samples */
+ samplepos_t source_beats_to_absolute_samples(Evoral::Beats beats) const;
+ /** Convert a timestamp in beats measured from source start into region-relative samples */
+ samplepos_t source_beats_to_region_samples(Evoral::Beats beats) const {
+ return source_beats_to_absolute_samples (beats) - _region->position();
}
- /** Convert a timestamp in absolute frames to beats measured from source start*/
- Evoral::Beats absolute_frames_to_source_beats(framepos_t) const;
+ /** Convert a timestamp in absolute samples to beats measured from source start*/
+ Evoral::Beats absolute_samples_to_source_beats(samplepos_t) const;
- ARDOUR::BeatsFramesConverter const & region_relative_time_converter () const {
+ ARDOUR::BeatsSamplesConverter const & region_relative_time_converter () const {
return _region_relative_time_converter;
}
- ARDOUR::BeatsFramesConverter const & source_relative_time_converter () const {
+ ARDOUR::BeatsSamplesConverter const & source_relative_time_converter () const {
return _source_relative_time_converter;
}
- ARDOUR::DoubleBeatsFramesConverter const & region_relative_time_converter_double () const {
+ ARDOUR::DoubleBeatsSamplesConverter const & region_relative_time_converter_double () const {
return _region_relative_time_converter_double;
}
@@ -327,13 +327,13 @@ public:
void trim_front_ending ();
/** Add a note to the model, and the view, at a canvas (click) coordinate.
* \param t time in frames relative to the position of the region
* \param y vertical position in pixels
* \param length duration of the note in beats
* \param state the keyboard modifier mask for the canvas event (click).
* \param shift_snap true alters snap behavior to round down always (false if the gui has already done that).
*/
- void create_note_at (framepos_t t, double y, Evoral::Beats length, uint32_t state, bool shift_snap);
+ void create_note_at (samplepos_t t, double y, Evoral::Beats length, uint32_t state, bool shift_snap);
/** An external request to clear the note selection, remove MRV from editor
* selection.
@@ -399,7 +399,7 @@ private:
void trim_note(NoteBase* ev, ARDOUR::MidiModel::TimeType start_delta,
ARDOUR::MidiModel::TimeType end_delta);
- void update_drag_selection (framepos_t start, framepos_t end, double y0, double y1, bool extend);
+ void update_drag_selection (samplepos_t start, samplepos_t end, double y0, double y1, bool extend);
void update_vertical_drag_selection (double last_y, double y, bool extend);
void add_to_selection (NoteBase*);
@@ -420,9 +420,9 @@ private:
typedef boost::unordered_map<ARDOUR::MidiModel::constSysExPtr, boost::shared_ptr<SysEx> > SysExes;
typedef std::vector<NoteBase*> CopyDragEvents;
- ARDOUR::BeatsFramesConverter _region_relative_time_converter;
- ARDOUR::BeatsFramesConverter _source_relative_time_converter;
- ARDOUR::DoubleBeatsFramesConverter _region_relative_time_converter_double;
+ ARDOUR::BeatsSamplesConverter _region_relative_time_converter;
+ ARDOUR::BeatsSamplesConverter _source_relative_time_converter;
+ ARDOUR::DoubleBeatsSamplesConverter _region_relative_time_converter_double;
boost::shared_ptr<ARDOUR::MidiModel> _model;
Events _events;
@@ -503,7 +503,7 @@ private:
void data_recorded (boost::weak_ptr<ARDOUR::MidiSource>);
/** Get grid type as beats, or default to 1 if not snapped to beats. */
- Evoral::Beats get_grid_beats(framepos_t pos) const;
+ Evoral::Beats get_grid_beats(samplepos_t pos) const;
void remove_ghost_note ();
void mouse_mode_changed ();
@@ -511,7 +511,7 @@ private:
void leave_internal ();
void hide_verbose_cursor ();
- framecnt_t _last_display_zoom;
+ samplecnt_t _last_display_zoom;
double _last_event_x;
double _last_event_y;
@@ -524,7 +524,7 @@ private:
Gtkmm2ext::Color _patch_change_outline;
Gtkmm2ext::Color _patch_change_fill;
- Evoral::Beats snap_frame_to_grid_underneath (framepos_t p, int32_t divisions, bool shift_snap) const;
+ Evoral::Beats snap_sample_to_grid_underneath (samplepos_t p, int32_t divisions, bool shift_snap) const;
PBD::ScopedConnection _mouse_mode_connection;
@@ -259,42 +259,42 @@ public:
* @param ensure_snap ignore SnapOff and magnetic snap.
* Required for inverting snap logic with modifier keys and snap delta calculation.
- * @return the snapped framepos_t coordinate relative to region start
+ * @return the snapped samplepos_t coordinate relative to region start
*/
@@ -327,13 +327,13 @@ public:
void trim_front_ending ();
/** Add a note to the model, and the view, at a canvas (click) coordinate.
- * \param t time in frames relative to the position of the region
+ * \param t time in samples relative to the position of the region
* \param y vertical position in pixels
* \param length duration of the note in beats